#ifndef CLEAN900_H
#define CLEAN900_H

#include <QMainWindow>

namespace Ui {
    class CleaN900;
}

class CleaN900 : public QMainWindow
{
    Q_OBJECT

public:
    explicit CleaN900(QWidget *parent = 0);
    ~CleaN900();

private:
    Ui::CleaN900 *ui;

private slots:
    void on_silent_clicked();
    void on_general_clicked();
    void on_enblue_clicked();
    void on_enfm_clicked();
    void on_encell_clicked();
    void on_diblue_clicked();
    void on_difm_clicked();
    void on_pushButton_clicked();
    void on_search_clicked();
    void on_searchMy_clicked();
    void on_searchhome_clicked();
    void on_actionDonate_triggered();
    void on_actionHardware_Details_triggered();
    void on_pushDpkgPurge_clicked();
    void on_pushDet_clicked();
    void on_pushPart_clicked();
    void on_pushUpTem_clicked();
    void on_pushApp_clicked();
    void on_pushBat_clicked();
    void on_pushCard_clicked();
    void on_pushOpt_clicked();
    void on_pushRam_clicked();
    void on_pushMydocs_clicked();
    void on_pushRoot_clicked();
    void on_pushReboot_2_clicked();
    void on_pushRemove_clicked();
    void on_pushInstall_clicked();
    void on_pushRip_clicked();
    void on_pushBackup_clicked();
    void on_pushReboot_clicked();
    void on_pushUpgrade_clicked();
    void on_pushUpdate_clicked();
    void on_pushPurge_clicked();
    void on_pushAutoremove_clicked();
    void on_pushAutoclean_clicked();
    void on_pushClean_clicked();
    void on_commandLinkButton_clicked();
    void on_actionXTerm_triggered();
    void on_actionAbout_triggered();
};

#endif // CLEAN900_H
